@@ -51,6 +51,7 @@ def render_cqrs_handler(
     handler_type: str,
     layer_folder: str,
     folder_name: str,
+    app_module: str,
     input_file: str,
     input_class: str,
     input_var: str,
@@ -68,6 +69,7 @@ def render_cqrs_handler(
         handler_type_lower=handler_type_lower,
         layer_folder=layer_folder,
         folder_name=folder_name,
+        app_module=app_module,
         input_file=input_file,
         input_class=input_class,
         input_var=input_var,
